==> modified-shop_1.06-r4642_install.zip: modified-shop_1.06-r4642_install/shoproot/lang/english/admin/index.php <==
<?php
/* --------------------------------------------------------------
   $Id: index.php 899 2005-04-29 02:40:57Z hhgag $

   XT-Commerce - community made shopping
   http://www.xt-commerce.com

   Copyright (c) 2003 XT-Commerce
   --------------------------------------------------------------
   based on:
   (c) 2000-2001 The Exchange Project  (earlier name of osCommerce)
   (c) 2002-2003 osCommerce(index.php,v 1.5 2002/03/30); www.oscommerce.com
   (c) 2003	 nextcommerce (index.php,v 1.5 2003/08/14); www.nextcommerce.org

   Released under the GNU General Public License
   --------------------------------------------------------------*/

define('HEADING_TITLE', 'Choose an action...');

define('BOX_TITLE_ORDERS', 'Orders');
define('BOX_TITLE_STATISTICS', 'Statistics');

define('BOX_ENTRY_SUPPORT_SITE', 'Support Site');
define('BOX_ENTRY_SUPPORT_FORUMS', 'Support Forums');
define('BOX_ENTRY_MAILING_LISTS', 'Mailing Lists');
define('BOX_ENTRY_BUG_REPORTS', 'Bug Reports');
define('BOX_ENTRY_FAQ', 'FAQ');
define('BOX_ENTRY_LIVE_DISCUSSIONS', 'Live Discussions');
define('BOX_ENTRY_CVS_REPOSITORY', 'CVS Repository');
define('BOX_ENTRY_INFORMATION_PORTAL', 'Information Portal');

define('BOX_ENTRY_CUSTOMERS', 'Customers:');
define('BOX_ENTRY_PRODUCTS', 'Products:');
define('BOX_ENTRY_REVIEWS', 'Reviews:');

define('BOX_CONNECTION_PROTECTED', 'You are protected by a %s secure SSL Connection.');
define('BOX_CONNECTION_UNPROTECTED', 'You are <font color="#ff0000">not</font> protected by a secure SSL connection.');
define('BOX_CONNECTION_UNKNOWN', 'unknown');

define('BOX_HEADING_CONFIGURATION', 'Configuration');
define('BOX_CONFIGURATION_MYSTORE', 'My Shop');
define('BOX_CONFIGURATION_LOGGING', 'Logging Informations');
define('BOX_CONFIGURATION_CACHE', 'Cache Options');

define('BOX_MODULES_PAYMENT', 'Payment Method');
define('BOX_MODULES_SHIPPING', 'Shipping Method');

define('BOX_CATALOG_MANUFACTURERS', 'Manufacturers');

define('BOX_CUSTOMERS_CUSTOMERS', 'Customers');
define('BOX_CUSTOMERS_ORDERS', 'Orders');
define('BOX_CUSTOMERS_ACCOUNTING', 'Accounting');

define('BOX_TAXES_COUNTRIES', 'Countries');
define('BOX_TAXES_GEO_ZONES', 'Zones');

define('BOX_LOCALIZATION_CURRENCIES', 'Currencies');
define('BOX_LOCALIZATION_LANGUAGES', 'Languages');

define('CATALOG_CONTENTS', 'Content');

define('REPORTS_PRODUCTS', 'Products');
define('REPORTS_ORDERS', 'Orders');

define('TOOLS_BACKUP', 'Backup');
define('TOOLS_BANNERS', 'Banners');
define('TOOLS_FILES', 'Files');
?>

==> modified-shop_2.0.7.2-r14622_install.zip: modified-shop_2.0.7.2-r14622_install/shoproot/lang/english/admin/index.php <==
<?php
/* --------------------------------------------------------------
   $Id: index.php 899 2005-04-29 02:40:57Z hhgag $

   XT-Commerce - community made shopping
   http://www.xt-commerce.com

   Copyright (c) 2003 XT-Commerce
   --------------------------------------------------------------
   based on:
   (c) 2000-2001 The Exchange Project  (earlier name of osCommerce)
   (c) 2002-2003 osCommerce(index.php,v 1.5 2002/03/30); www.oscommerce.com
   (c) 2003	 nextcommerce (index.php,v 1.5 2003/08/14); www.nextcommerce.org

   Released under the GNU General Public License
   --------------------------------------------------------------*/

define('HEADING_TITLE', 'Choose an action...');

define('BOX_TITLE_ORDERS', 'Orders');
define('BOX_TITLE_STATISTICS', 'Statistics');

define('BOX_ENTRY_SUPPORT_SITE', 'Support Site');
define('BOX_ENTRY_SUPPORT_FORUMS', 'Support Forums');
define('BOX_ENTRY_MAILING_LISTS', 'Mailing Lists');
define('BOX_ENTRY_BUG_REPORTS', 'Bug Reports');
define('BOX_ENTRY_FAQ', 'FAQ');
define('BOX_ENTRY_LIVE_DISCUSSIONS', 'Live Discussions');
define('BOX_ENTRY_CVS_REPOSITORY', 'CVS Repository');
define('BOX_ENTRY_INFORMATION_PORTAL', 'Information Portal');

define('BOX_ENTRY_CUSTOMERS', 'Customers:');
define('BOX_ENTRY_PRODUCTS', 'Products:');
define('BOX_ENTRY_REVIEWS', 'Reviews:');

define('BOX_CONNECTION_PROTECTED', 'You are protected by a %s secure SSL Connection.');
define('BOX_CONNECTION_UNPROTECTED', 'You are <span class="col-red">not</span> protected by a secure SSL connection.');
define('BOX_CONNECTION_UNKNOWN', 'unknown');

define('BOX_HEADING_CONFIGURATION', 'Configuration');
define('BOX_CONFIGURATION_MYSTORE', 'My Shop');
define('BOX_CONFIGURATION_LOGGING', 'Logging Informations');
define('BOX_CONFIGURATION_CACHE', 'Cache Options');

define('BOX_MODULES_PAYMENT', 'Payment Method');
define('BOX_MODULES_SHIPPING', 'Shipping Method');

define('BOX_CATALOG_MANUFACTURERS', 'Manufacturers');

define('BOX_CUSTOMERS_CUSTOMERS', 'Customers');
define('BOX_CUSTOMERS_ORDERS', 'Orders');
define('BOX_CUSTOMERS_ACCOUNTING', 'Accounting');

define('BOX_TAXES_COUNTRIES', 'Countries');
define('BOX_TAXES_GEO_ZONES', 'Zones');

define('BOX_LOCALIZATION_CURRENCIES', 'Currencies');
define('BOX_LOCALIZATION_LANGUAGES', 'Languages');

define('CATALOG_CONTENTS', 'Content');

define('REPORTS_PRODUCTS', 'Products');
define('REPORTS_ORDERS', 'Orders');

define('TOOLS_BACKUP', 'Backup');
define('TOOLS_BANNERS', 'Banners');
define('TOOLS_FILES', 'Files');
?>
